SystemOrganization addCategory: #SimpleContactManager!
SystemOrganization addCategory: #'SimpleContactManager-Core'!
SystemOrganization addCategory: #'SimpleContactManager-Core-Tests'!
SystemOrganization addCategory: #'SimpleContactManager-Web'!

TestCase subclass: #ContactBookTest
	instanceVariableNames: 'defaultBook'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SimpleContactManager-Core-Tests'!

!ContactBookTest methodsFor: 'running' stamp: 'PeterPesch 6/29/2020 15:27'!
setUp
	"Hooks that subclasses may override to define the fixture of test."
	super setUp.
	defaultBook := ContactBook createDefault
! !

!ContactBookTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 15:28'!
testAddContact
	| contact before after |
	contact := Contact newNamed: 'Jan' email: 'abc@def.ghi'.
	before := defaultBook contacts size.
	defaultBook addContact: contact.
	after := defaultBook contacts size.
	defaultBook removeContact: contact.
	self assert: after equals: before + 1.
	! !

!ContactBookTest methodsFor: 'tests' stamp: 'PeterPesch 7/1/2020 10:15'!
testContacts
	| myContacts found |
	myContacts := defaultBook contacts.
	found := (myContacts select: 
					[ :contact |
							(contact fullname = 'Clara Allende') &
							(contact email = 'clari.allende@gmail.com') ]) size.
	self assert: myContacts size equals: 4.
	self assert: found equals: 1.! !

!ContactBookTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 15:29'!
testRemoveContact
	| contact before after |
	contact := Contact newNamed: 'Jan' email: 'abc@def.ghi'.
	before := defaultBook contacts size.
	defaultBook addContact: contact.
	after := defaultBook contacts size.
	defaultBook removeContact: contact.
	self assert: after equals: before + 1.
	! !

TestCase subclass: #ContactTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SimpleContactManager-Core-Tests'!

!ContactTest methodsFor: 'tests' stamp: 'PeterPesch 6/29/2020 15:00'!
testCreation
	| contact |
	contact := Contact
		newNamed: 'Marcus Denker'
		email: 'marcus.denker@inria.fr'.
	self assert: contact fullname equals: 'Marcus Denker'.
	self assert: contact email equals: 'marcus.denker@inria.fr'.! !

!ContactTest methodsFor: 'tests' stamp: 'PeterPesch 7/1/2020 09:54'!
testEmail
	| contact |
	contact := Contact
		newNamed: 'Marcus Denker'
		email: 'marcus.denker@inria.fr'.
	contact email: 'other@inria.com'.
	self assert: contact email equals: 'other@inria.com'.! !

!ContactTest methodsFor: 'tests' stamp: 'PeterPesch 7/1/2020 09:56'!
testFullname
	| contact |
	contact := Contact
		newNamed: 'Marcus Denker'
		email: 'marcus.denker@inria.fr'.
	contact fullname: 'Other Name'.
	self assert: contact fullname equals: 'Other Name'.
! !

!ContactTest methodsFor: 'tests' stamp: 'PeterPesch 7/1/2020 13:30'!
testGravatarUrl
	| contact |
	contact := Contact
		newNamed: 'Marcus Denker'
		email: 'marcus.denker@inria.fr'.
	contact email: 'other@inria.com'.
	self assert: contact gravatarUrl equals: 'http://www.gravatar.com/avatar/658de129b77ef5697115af56f4ed3b7f.jpg'.! !

!ContactTest methodsFor: 'tests' stamp: 'PeterPesch 7/1/2020 09:50'!
testNewnamedEmail
	| contact |
	contact := Contact
		newNamed: 'Marcus Denker'
		email: 'marcus.denker@inria.fr'.
	self assert: contact fullname equals: 'Marcus Denker'.
	self assert: contact email equals: 'marcus.denker@inria.fr'.! !

WAComponent subclass: #WAContact
	instanceVariableNames: 'contact'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SimpleContactManager-Web'!

!WAContact commentStamp: 'PeterPesch 7/1/2020 12:46' prior: 0!
I am a Component for editing a Contact via the simple Web View for the ContactBook.

For the Responsibility part: Three sentences about my main responsibilities - what I do, what I know.

For the Collaborators Part: State my main collaborators and one line about how I interact with them. 

Public API and Key Messages

- message one   
- message two 
- (for bonus points) how to create instances.

   One simple example is simply gorgeous.
 
Internal Representation and Key Implementation Points.

    Instance Variables
	contact:		<Object>


    Implementation Points!

!WAContact class methodsFor: 'as yet unclassified' stamp: 'PeterPesch 7/1/2020 12:48'!
editContact: aContact
	^ self new
		setContact: aContact;
		yourself! !

!WAContact methodsFor: 'accessing' stamp: 'PeterPesch 7/1/2020 12:49'!
contact
	^ contact! !

!WAContact methodsFor: 'initialization' stamp: 'PeterPesch 7/1/2020 12:49'!
initialize
	super initialize.
	contact := Contact new.! !

!WAContact methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 13:16'!
renderButtonsOn: html
	html tbsFormGroup: [
		html tbsButtonGroup: [
			self
				renderSubmitButtonOn: html;
				renderCancelButtonOn: html ] ]! !

!WAContact methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 13:00'!
renderCancelButtonOn: html
	html tbsButton
	beDanger;
	cancelCallback: [ self answer: nil ];
	with: 'Cancel'! !

!WAContact methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 12:58'!
renderContentOn: html
	html tbsContainer: [
		html heading with: 'Contact Editing'.
		html tbsForm with: [
			self renderFieldsOn: html.
			self renderButtonsOn: html ] ]! !

!WAContact methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 12:56'!
renderEmailFieldOn: html
	html tbsFormGroup: [
		html label: 'Email'.
		html emailInput
			tbsFormControl;
			placeholder: 'your@email.eu';
			callback: [ :email | self contact email: email address ];
			value: (self contact email ifNil: '') ]! !

!WAContact methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 12:53'!
renderFieldsOn: html
	self renderFullnameFieldOn: html.
	self renderEmailFieldOn: html! !

!WAContact methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 12:54'!
renderFullnameFieldOn: html
	html tbsFormGroup: [
		html label: 'Fullname'.
		html textInput
			tbsFormControl;
			placeholder: 'fullname';
			callback: [ :value | self contact fullname: value ];
			value: (self contact fullname ifNil: '') ]! !

!WAContact methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 12:59'!
renderSubmitButtonOn: html
	html tbsSubmitButton
		beSuccess;
		bePrimary;
		callback: [ self answer: self contact ];
		with: 'Save'! !

!WAContact methodsFor: 'action' stamp: 'PeterPesch 7/1/2020 12:49'!
setContact: aContact
	contact := aContact! !

WAComponent subclass: #WAContactBook
	instanceVariableNames: 'contactBook'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SimpleContactManager-Web'!

!WAContactBook commentStamp: 'PeterPesch 7/1/2020 10:59' prior: 0!
I am the top-level component for the simple Web View for the ContactBook.

For the Responsibility part: Three sentences about my main responsibilities - what I do, what I know.

For the Collaborators Part: State my main collaborators and one line about how I interact with them. 

Public API and Key Messages

- message one   
- message two 
- (for bonus points) how to create instances.

   One simple example is simply gorgeous.
 
Internal Representation and Key Implementation Points.


    Implementation Points!

!WAContactBook class methodsFor: 'class initialization' stamp: 'PeterPesch 7/1/2020 11:34'!
initialize
	"register this class to thr /contacts URL path."
	"Declare dependency n Bootstrap."
	(WAAdmin register: self asApplicationAt: 'contacts')
		addLibrary: JQDeploymentLibrary;
		addLibrary: TBSDeploymentLibrary.
! !

WAContactBook initialize!

!WAContactBook methodsFor: 'adding' stamp: 'PeterPesch 7/1/2020 13:22'!
addContact
	(self call: WAContact new)
		ifNotNil: [ :contact | contactBook addContact: contact ]! !

!WAContactBook methodsFor: 'accessing' stamp: 'PeterPesch 7/1/2020 11:23'!
contactBook
	^ contactBook ifNil: [ contactBook := ContactBook createDefault ]! !

!WAContactBook methodsFor: 'accessing' stamp: 'PeterPesch 7/1/2020 11:22'!
contacts
	^ self contactBook contacts! !

!WAContactBook methodsFor: 'enumerating' stamp: 'PeterPesch 7/1/2020 11:24'!
contactsDo: aBlock
	self contacts do: aBlock! !

!WAContactBook methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 13:04'!
renderButtonsForContact: aContact on: html
	html tbsButtonGroup: [
		self
			renderEditButtonForContact: aContact on: html;
			renderRemoveButtonForContact: aContact on: html ]! !

!WAContactBook methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 13:02'!
renderContact: aContact on: html
	"Render a Contact as a table row."
	html tableRow: [
		html
			tableData: aContact fullname;
			tableData: aContact email;
			tableData: [ self renderPhotoOf: aContact on: html ];
			tableData: [ self renderButtonsForContact: aContact on: html ] ]! !

!WAContactBook methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 11:45'!
renderContactsOn: html
	"Define a table with the header, and let the table rows render themselves."
	html tbsTable: [
		html tableHead: [
			html
				tableHeading: 'Name';
				tableHeading: 'Email';
				tableHeading: 'Photo' ].
		self contactsDo: [ :contact | self renderContact: contact on: html ] ]
! !

!WAContactBook methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 13:21'!
renderContentOn: html
	"Main entry point of the view."
	"Render a title and the list of contacts."
	html tbsContainer: [ 
		html heading
			level: 1;
			with: 'My Contact Book'.
		html tbsForm: [ 
			self renderContactsOn: html.
			self renderGlobalButtonsOn: html ] ]
! !

!WAContactBook methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 13:04'!
renderEditButtonForContact: aContact on: html
	html tbsButton
		beSuccess;
		callback: [ self call: (WAContact editContact: aContact) ];
		with: 'Edit'! !

!WAContactBook methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 13:21'!
renderGlobalButtonsOn: html
	html tbsButtonGroup: [
		html tbsButton
			beSuccess;
			callback: [ self addContact ];
			with: 'New contact' ]! !

!WAContactBook methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 11:48'!
renderPhotoOf: aContact on: html
	html image url: aContact gravatarUrl! !

!WAContactBook methodsFor: 'rendering' stamp: 'PeterPesch 7/1/2020 12:14'!
renderRemoveButtonForContact: aContact on: html
	html tbsButton
	beDanger;
	callback: [ self contactBook removeContact: aContact ];
	with: 'Remove'! !

!WAContactBook methodsFor: 'updating' stamp: 'PeterPesch 7/1/2020 11:17'!
updateRoot: anHtmlRoot
	"Set the title of the Web Page."
	"The title will be visible as title of the web browser window."
	super updateRoot: anHtmlRoot.
	anHtmlRoot title: 'Contact Book'! !

Object subclass: #Contact
	instanceVariableNames: 'fullname email'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SimpleContactManager-Core'!

!Contact commentStamp: 'PeterPesch 6/29/2020 15:11' prior: 0!
I represent a person within the contact book application.

For the Responsibility part: Three sentences about my main responsibilities - what I do, what I know.

For the Collaborators Part: State my main collaborators and one line about how I interact with them. 

Public API and Key Messages

- message one   
- message two 
- (for bonus points) how to create instances.

   One simple example is simply gorgeous.
 
Internal Representation and Key Implementation Points.

    Instance Variables
	email:		<Object>
	fullname:		<Object>


    Implementation Points!

!Contact class methodsFor: 'instance creation' stamp: 'PeterPesch 6/29/2020 14:57'!
newNamed: aNameString email: anEmailString
	^ self new
	fullname: aNameString;
	email: anEmailString;
	yourself! !

!Contact methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 14:58'!
email
	^ email! !

!Contact methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 14:58'!
email: aString
	email := aString! !

!Contact methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 14:58'!
fullname
	^ fullname! !

!Contact methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 14:58'!
fullname: aString
	fullname := aString! !

!Contact methodsFor: 'accessing' stamp: 'PeterPesch 7/1/2020 11:43'!
gravatarUrl
	"Fetch a photo for this email address using gravatar."
	^ 'http://www.gravatar.com/avatar/',
		(MD5 hashMessage: email trimBoth asLowercase) hex, '.jpg'! !

!Contact methodsFor: 'printing' stamp: 'PeterPesch 6/29/2020 15:08'!
printOn: aStream
	aStream
		nextPutAll: self fullname;
		nextPutAll: ' <';
		nextPutAll: self email;
		nextPutAll: '>'! !

Object subclass: #ContactBook
	instanceVariableNames: 'contacts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SimpleContactManager-Core'!

!ContactBook commentStamp: 'PeterPesch 6/29/2020 15:10' prior: 0!
I am a simple contact book application with a web interface.

For the Responsibility part: Three sentences about my main responsibilities - what I do, what I know.

For the Collaborators Part: State my main collaborators and one line about how I interact with them. 

Public API and Key Messages

- message one   
- message two 
- (for bonus points) how to create instances.

   One simple example is simply gorgeous.
 
Internal Representation and Key Implementation Points.

    Instance Variables
	contacts:		<Object>


    Implementation Points!

!ContactBook class methodsFor: 'current' stamp: 'PeterPesch 6/29/2020 15:18'!
createDefault
	^ self new
	addContact: (Contact
		newNamed: 'Damien Cassou'
		email: 'damien@cassou.me');
	addContact: (Contact
		newNamed: 'Marcus Denker'
		email: 'marcus.denker@inria.fr');
	addContact: (Contact
		newNamed: 'Tudor Girba'
		email: 'tudor@tudorgirba.com');
	addContact: (Contact
		newNamed: 'Clara Allende'
		email: 'clari.allende@gmail.com');
	yourself! !

!ContactBook methodsFor: 'action' stamp: 'PeterPesch 6/29/2020 15:12'!
addContact: aContact
	self contacts add: aContact! !

!ContactBook methodsFor: 'accessing' stamp: 'PeterPesch 6/29/2020 15:12'!
contacts
	^ contacts ifNil: [ contacts := OrderedCollection new ]! !

!ContactBook methodsFor: 'action' stamp: 'PeterPesch 6/29/2020 15:12'!
removeContact: aContact
	self contacts remove: aContact! !

WAContactBook initialize!
